import{P as g}from"./PlayerNavbar-DKmAVloK.js";import{e as _,an as i,r as h,b,y,f as k,g as v,D as w,j as n,m as L,ab as C,ai as I,h as c,aO as N}from"./jwt-decode.esm-BTkSWSoY.js";import{u as D}from"./workspaceStore-JLfI-nyq.js";import"./userStore-D3APQgTa.js";import"./metadata-BjViSiEy.js";import"./PhHouse.vue-DiK-93ch.js";import"./PhMagnifyingGlass.vue-D64xa5zz.js";import"./PhRobot.vue-C7QW85Qb.js";import"./PhWebhooksLogo.vue--PAO9kNH.js";import"./LoadingOutlined-jh8ifNzZ.js";import"./PhSignOut.vue-Da3dVaPa.js";import"./index-DwbVISn6.js";import"./runnerData-Dk9JFgLq.js";import"./url-Dh-2B4RL.js";import"./colorHelpers-DxukDxoj.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="767bc54c-9eab-4423-a6ac-32e2a6deb7bf",o._sentryDebugIdIdentifier="sentry-dbid-767bc54c-9eab-4423-a6ac-32e2a6deb7bf")}catch{}})();const V={class:"main-container"},B={class:"content"},R=_({__name:"Main",setup(o){const e=I(),t=D(),p=i().path,a=h(null),u=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},d=()=>{e.push({name:"playerLogin"})},l=()=>{e.push({name:"playerLogin"})},m=b(()=>!!i().meta.hideLogin);return(r,s)=>{const f=C("RouterView");return c(),y("div",V,[n(t).state.workspace?(c(),k(g,{key:0,"current-path":n(p),"hide-login":m.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:u,onLoginClick:l,onLogoutClick:d},null,8,["current-path","hide-login","runner-data","loading"])):v("",!0),w("section",B,[L(f)])])}}}),J=N(R,[["__scopeId","data-v-f095bece"]]);export{J as default};
//# sourceMappingURL=Main-B19SkZkx.js.map
