const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["assets/OidcLoginCallback-aGrNLKoG.js","assets/workspaceStore-JLfI-nyq.js","assets/jwt-decode.esm-BTkSWSoY.js","assets/jwt-decode-B8mDiS39.css","assets/userStore-D3APQgTa.js","assets/runnerData-Dk9JFgLq.js","assets/url-Dh-2B4RL.js","assets/colorHelpers-DxukDxoj.js","assets/OidcLogoutCallback-CeE2zq1Y.js","assets/Login-Doiz9XmI.js","assets/Login.vue_vue_type_script_setup_true_lang-C64TDbmX.js","assets/OTPInput-o9c8lVvn.js","assets/OTPInput-DkitIIgo.css","assets/Logo-BqncmwK6.js","assets/Logo-D2kepPyK.css","assets/string-BYKRCdEY.js","assets/CircularLoading-Cj48YoIc.js","assets/CircularLoading-BiyobKo3.css","assets/index-Cx6QAF3K.js","assets/Login-D3Bo1XNf.css","assets/Login-CobhrWJT.css","assets/Main-B19SkZkx.js","assets/PlayerNavbar-DKmAVloK.js","assets/metadata-BjViSiEy.js","assets/PhHouse.vue-DiK-93ch.js","assets/PhMagnifyingGlass.vue-D64xa5zz.js","assets/PhRobot.vue-C7QW85Qb.js","assets/PhWebhooksLogo.vue--PAO9kNH.js","assets/LoadingOutlined-jh8ifNzZ.js","assets/PhSignOut.vue-Da3dVaPa.js","assets/index-DwbVISn6.js","assets/PlayerNavbar-CeGdx3sX.css","assets/Main-DqPmGmnC.css","assets/Home-CoMt6oaf.js","assets/Watermark-B-pDMBCW.js","assets/constants-C5LkWXsh.js","assets/Watermark-Fl_4jwe9.css","assets/PhArrowSquareOut.vue-DhcCIeu5.js","assets/index-Dcl-gnVg.js","assets/Home-C1q_HTgM.css","assets/Error-s71G9RKm.js","assets/AbstraLogo.vue_vue_type_script_setup_true_lang-CrhW1rUa.js","assets/logo-BiWG9_W5.js","assets/Error-CIbhyrKS.css","assets/Form-CbmdbWi2.js","assets/FormRunner-CCwjx0px.js","assets/Steps-ByO3nIj-.js","assets/index-D5EXyqg1.js","assets/Steps-D24tH1sk.css","assets/FormRunner-B8n6lTkp.css","assets/redirect-D-U_zSKN.js","assets/asyncComputed-DyfgKCRs.js","assets/uuid-DNWN2up9.js","assets/Form-CshGBPDC.css"])))=>i.map(i=>d[i]);
import{c as u,a as d,_ as t,u as l}from"./jwt-decode.esm-BTkSWSoY.js";import{u as p}from"./userStore-D3APQgTa.js";import{a as _}from"./workspaceStore-JLfI-nyq.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="cf5accf6-aeb8-4ec9-818d-b0c15c139299",e._sentryDebugIdIdentifier="sentry-dbid-cf5accf6-aeb8-4ec9-818d-b0c15c139299")}catch{}})();const h=[{path:"/oidc-login-callback",name:"oidcLoginCallback",component:()=>t(()=>import("./OidcLoginCallback-aGrNLKoG.js"),__vite__mapDeps([0,1,2,3,4,5,6,7])),meta:{allowUnauthenticated:!0}},{path:"/oidc-logout-callback",name:"oidcLogoutCallback",component:()=>t(()=>import("./OidcLogoutCallback-CeE2zq1Y.js"),__vite__mapDeps([8,1,2,3,4,5,6,7])),meta:{allowUnauthenticated:!0}},{path:"/login",name:"playerLogin",component:()=>t(()=>import("./Login-Doiz9XmI.js"),__vite__mapDeps([9,10,2,3,1,4,5,6,7,11,12,13,14,15,16,17,18,19,20])),meta:{allowUnauthenticated:!0}},{path:"/",name:"main",component:()=>t(()=>import("./Main-B19SkZkx.js"),__vite__mapDeps([21,22,4,2,3,1,5,6,7,23,24,25,26,27,28,29,30,31,32])),redirect:{name:"main"},children:[{path:"",name:"playerHome",component:()=>t(()=>import("./Home-CoMt6oaf.js"),__vite__mapDeps([33,23,24,2,3,25,26,27,34,1,4,5,6,7,35,36,37,38,28,39])),meta:{title:"Home"}},{path:"_player/threads",redirect:{name:"playerThreads"}},{path:"error/:status",name:"error",component:()=>t(()=>import("./Error-s71G9RKm.js"),__vite__mapDeps([40,41,42,13,2,3,14,35,1,4,5,6,7,38,43])),meta:{allowUnauthenticated:!0}},{path:":path(.*)*",name:"form",component:()=>t(()=>import("./Form-CbmdbWi2.js"),__vite__mapDeps([44,4,2,3,45,10,1,5,6,7,11,12,13,14,15,16,17,18,19,46,47,48,34,35,36,49,50,51,52,53])),meta:{hideLogin:!0}}]}],i=u({history:d("/"),routes:h,scrollBehavior(e){if(e.hash)return{el:e.hash}}}),f=e=>async(a,o)=>{if(l(a,o),a.meta.allowUnauthenticated)return;const r=p();r.loadJWT();const c=await _(a.path),{redirect:s,...m}=a.query;switch(c.status){case"ALLOWED":break;case"UNAUTHORIZED":{const n=r.email;r.removeJWT(),await e.push({name:"playerLogin",query:{...m,redirect:s||a.path,reauth:n?"true":void 0,email:n||void 0},params:a.params});break}case"NOT_FOUND":await e.push({name:"error",params:{status:"404"}});break;default:await e.push({name:"error",params:{status:"403"}})}};i.beforeEach(f(i));export{h as a,f as g,i as r};
//# sourceMappingURL=router-i76tskya.js.map
