import{e as _,ai as m,an as p,i as n,f,h as d,w as i,y,V as g,a2 as v,m as w,j as r,D as k,t as I}from"./jwt-decode.esm-BTkSWSoY.js";import{A as D,T}from"./index-Dcl-gnVg.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="30eda536-ad0a-4153-8d7e-26b2eb07e711",e._sentryDebugIdIdentifier="sentry-dbid-30eda536-ad0a-4153-8d7e-26b2eb07e711")}catch{}})();const x=_({__name:"TablesTabs",setup(e){const a=m(),t=p(),u=String(t.name),b=t.params.projectId,l=[{label:n.translate("i18n_tablestabs_tables_list"),value:"tables"},{label:n.translate("i18n_tablestabs_diagram_view"),value:"tables-diagram"},{label:n.translate("i18n_tablestabs_run_sql"),value:"sql"}],c=o=>{a.push({name:String(o),params:{projectId:b}})};return(o,h)=>(d(),f(r(T),{"active-key":r(u),options:l,"onUpdate:activeKey":c},{default:i(()=>[(d(),y(g,null,v(l,s=>w(r(D),{key:s.value,name:s.value},{tab:i(()=>[k("span",null,I(s.label),1)]),_:2},1032,["name"])),64))]),_:1},8,["active-key"]))}});export{x as _};
//# sourceMappingURL=TablesTabs.vue_vue_type_script_setup_true_lang-ChGQZAZm.js.map
