import{e as s,y as a,h as o,m as r,j as d,b8 as c,aO as i}from"./jwt-decode.esm-BTkSWSoY.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="e3e19986-00c2-458c-a971-502321394bb5",e._sentryDebugIdIdentifier="sentry-dbid-e3e19986-00c2-458c-a971-502321394bb5")}catch{}})();const _={class:"centered"},f=s({__name:"LoadingContainer",setup(e){return(n,t)=>(o(),a("div",_,[r(d(c))]))}}),b=i(f,[["__scopeId","data-v-52e6209a"]]);export{b as L};
//# sourceMappingURL=LoadingContainer-DrHHo_f0.js.map
