import{C as f,T as m}from"./router-Dhyutz1M.js";import{e as u,b,i as d,f as i,g as y,h as r,j as s,w as t,B as c,k as l,t as o,m as p,T as k}from"./jwt-decode.esm-BTkSWSoY.js";import{A as _}from"./index-Cx6QAF3K.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="d97ac46f-96f0-4988-8cea-ab9f96d8a6c3",e._sentryDebugIdIdentifier="sentry-dbid-d97ac46f-96f0-4988-8cea-ab9f96d8a6c3")}catch{}})();const M=u({__name:"BillingAlert",props:{organizationId:{},billingMetadata:{}},setup(e){const a=e,n=b(()=>a.billingMetadata?.messageCTA??d.translate("i18n_billingalert_contact_us")),g=()=>{f.showNewMessage(d.translate("i18n_billingalert_help_message")),m.billingAlertCtaClicked(a.organizationId,n.value)};return(C,w)=>e.billingMetadata?.message?(r(),i(s(_),{key:0,type:"error"},{message:t(()=>[p(s(k),{type:"secondary"},{default:t(()=>[l(o(e.billingMetadata?.message),1)]),_:1})]),action:t(()=>[e.billingMetadata?.messageLink?(r(),i(s(c),{key:0,type:"primary",target:"_blank",href:e.billingMetadata.messageLink},{default:t(()=>[l(o(n.value),1)]),_:1},8,["href"])):(r(),i(s(c),{key:1,type:"primary",onClick:g},{default:t(()=>[l(o(n.value),1)]),_:1}))]),_:1})):y("",!0)}});export{M as _};
//# sourceMappingURL=BillingAlert.vue_vue_type_script_setup_true_lang-Cuq6ytsG.js.map
