import{A as n}from"./index-D5EXyqg1.js";import{e as o,b as r,y as a,g as c,O as d,m as f,j as l,h as p,aO as i}from"./jwt-decode.esm-BTkSWSoY.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="e140519a-f6cc-42dc-be32-0ed3532cec71",e._sentryDebugIdIdentifier="sentry-dbid-e140519a-f6cc-42dc-be32-0ed3532cec71")}catch{}})();const u=o({__name:"Steps",props:{stepsInfo:{},isPreview:{type:Boolean}},setup(e){const s=e,t=r(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",description:""})):[]);return(m,y)=>e.stepsInfo?(p(),a("nav",{key:0,class:d(["p-steps",{"full-screen":!e.isPreview}])},[f(l(n),{current:e.stepsInfo.current-1,items:t.value,responsive:!1},null,8,["current","items"])],2)):c("",!0)}}),_=i(u,[["__scopeId","data-v-58fdd395"]]);export{_ as S};
//# sourceMappingURL=Steps-ByO3nIj-.js.map
