import{_ as r}from"./logo-BiWG9_W5.js";import{L as o}from"./Logo-BqncmwK6.js";import{e as s,f as a,j as i,h as f}from"./jwt-decode.esm-BTkSWSoY.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ffb549f5-31a3-46ec-8793-6c08e978e054",e._sentryDebugIdIdentifier="sentry-dbid-ffb549f5-31a3-46ec-8793-6c08e978e054")}catch{}})();const u=s({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(t,n)=>(f(),a(o,{"image-url":i(r),"brand-name":"Abstra","hide-text":e.hideText,size:e.size??"small"},null,8,["image-url","hide-text","size"]))}});export{u as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang-CrhW1rUa.js.map
