import{_ as c}from"./Login.vue_vue_type_script_setup_true_lang-C64TDbmX.js";import{e as p,y as i,m as u,j as n,ai as m,an as f,h as l,aO as _}from"./jwt-decode.esm-BTkSWSoY.js";import{u as b}from"./workspaceStore-JLfI-nyq.js";import"./OTPInput-o9c8lVvn.js";import"./Logo-BqncmwK6.js";import"./string-BYKRCdEY.js";import"./CircularLoading-Cj48YoIc.js";import"./index-Cx6QAF3K.js";import"./userStore-D3APQgTa.js";import"./runnerData-Dk9JFgLq.js";import"./url-Dh-2B4RL.js";import"./colorHelpers-DxukDxoj.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="175fba0d-6e0d-4d3e-90b6-668f0b988def",e._sentryDebugIdIdentifier="sentry-dbid-175fba0d-6e0d-4d3e-90b6-668f0b988def")}catch{}})();const y={class:"runner"},g=p({__name:"Login",setup(e){const o=m(),r=f(),t=b(),d=async()=>{const{redirect:a,...s}=r.query;if(a){await o.push({path:a,query:s,params:r.params});return}o.push({name:"playerHome",query:s})};return(a,s)=>(l(),i("div",y,[u(c,{"logo-url":n(t).state.workspace?.logoUrl??void 0,"brand-name":n(t).state.workspace?.brandName,locale:n(t).state.workspace?.language??"en",onDone:d},null,8,["logo-url","brand-name","locale"])]))}}),R=_(g,[["__scopeId","data-v-12c690e1"]]);export{R as default};
//# sourceMappingURL=Login-Doiz9XmI.js.map
