import{N as l}from"./Navbar-BrOWlNE7.js";import{B as f}from"./BaseLayout-DJTg3w2I.js";import{C as b}from"./ContentLayout-DrPZmqye.js";import{e as g,an as _,b as r,ab as v,f as e,h as i,w as n,m as c,g as y}from"./jwt-decode.esm-BTkSWSoY.js";import{_ as w}from"./BillingAlert.vue_vue_type_script_setup_true_lang-Cuq6ytsG.js";import{u as z}from"./projectsStore-BgoZQQ5y.js";import"./logo-BiWG9_W5.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang-BiH5_J3e.js";import"./constants-C5LkWXsh.js";import"./keyboard-BHvBU_Kq.js";import"./os-PZojZFX-.js";import"./router-Dhyutz1M.js";import"./ts.worker-BQIuSwVW.js";import"./organization-BXLykhFT.js";import"./project-BOsxR6Ov.js";import"./record-ByQtEUH9.js";import"./tables-rIQ95qBT.js";import"./string-BYKRCdEY.js";import"./organizationSwitcher-Dynbd3X0.js";import"./folder-uFFLjpdv.js";import"./CreateProjectModal.vue_vue_type_script_setup_true_lang-wA5bnSRN.js";import"./member-NpIT6PfG.js";import"./index-kxRKvTGU.js";import"./index-Dcl-gnVg.js";import"./CreateTableModal.vue_vue_type_script_setup_true_lang-DNNk0_x4.js";import"./PhNotePencil.vue-DD50qc2W.js";import"./PhSignOut.vue-Da3dVaPa.js";import"./index-BKDGrwKH.js";import"./index-DwbVISn6.js";import"./PhPlus.vue-V3SIWk6s.js";import"./omniChatStore-CzchNX3R.js";import"./contracts.generated-ByAyIWn2.js";import"./runnerData-Dk9JFgLq.js";import"./url-Dh-2B4RL.js";import"./colorHelpers-DxukDxoj.js";import"./uuid-DNWN2up9.js";import"./PhCopySimple.vue-CtYcj4n2.js";import"./index-BP_A_hKA.js";import"./index-Cx6QAF3K.js";import"./ant-design-BGAUFfcz.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="bbc85809-5490-4c2b-8f69-0ab06b10060f",t._sentryDebugIdIdentifier="sentry-dbid-bbc85809-5490-4c2b-8f69-0ab06b10060f")}catch{}})();const ct=g({__name:"Organization",setup(t){const o=_(),m=z(),p=r(()=>o.params.organizationId),a=r(()=>m.fetchedState?.organization),u=r(()=>a.value?{organizationId:a.value.id}:void 0),s=r(()=>a.value?.billingMetadata);return(I,C)=>{const d=v("RouterView");return i(),e(f,null,{navbar:n(()=>[c(l,{"use-cascader":!0,"cascader-props":u.value},null,8,["cascader-props"])]),content:n(()=>[c(b,null,{default:n(()=>[s.value?(i(),e(w,{key:0,"billing-metadata":s.value,"organization-id":p.value},null,8,["billing-metadata","organization-id"])):y("",!0),(i(),e(d,{key:p.value}))]),_:1})]),_:1})}}});export{ct as default};
//# sourceMappingURL=Organization-dsUCwoFn.js.map
