import{O as d}from"./workspaceStore-JLfI-nyq.js";import{e as c,N as f,y as u,m as o,w as n,j as a,ao as _,T as b,k as r,t as s,i,h as p}from"./jwt-decode.esm-BTkSWSoY.js";import"./userStore-D3APQgTa.js";import"./runnerData-Dk9JFgLq.js";import"./url-Dh-2B4RL.js";import"./colorHelpers-DxukDxoj.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="e62ff18b-6e85-41b7-aa97-557f5ea64b7f",e._sentryDebugIdIdentifier="sentry-dbid-e62ff18b-6e85-41b7-aa97-557f5ea64b7f")}catch{}})();const D=c({__name:"OidcLogoutCallback",setup(e){return f(async()=>{await new d().logoutCallback()}),(t,l)=>(p(),u("div",null,[o(a(_),null,{default:n(()=>[r(s(a(i).translate("i18n_oidclogoutcallback_authenticated_title")),1)]),_:1}),o(a(b),null,{default:n(()=>[r(s(a(i).translate("i18n_oidclogoutcallback_close_window_message")),1)]),_:1})]))}});export{D as default};
//# sourceMappingURL=OidcLogoutCallback-CeE2zq1Y.js.map
