import{e as o,b as s,y as l,h as i,D as r,A as c,U as u,O as t,aO as y}from"./jwt-decode.esm-BTkSWSoY.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="c5b7da9d-86a8-413e-a3ac-a5dabcfee220",e._sentryDebugIdIdentifier="sentry-dbid-c5b7da9d-86a8-413e-a3ac-a5dabcfee220")}catch{}})();const f=o({__name:"ContentLayout",props:{fullWidth:{type:Boolean},noPadding:{type:Boolean},flexLayout:{type:Boolean},innerPadding:{}},setup(e){const a=e,n=s(()=>({...a.innerPadding&&{padding:a.innerPadding}}));return(d,p)=>(i(),l("div",{class:t(["content-layout",{"no-padding":e.noPadding}])},[r("div",{class:t(["centered-layout",{"full-width":e.fullWidth,"flex-layout":e.flexLayout}]),style:u(n.value)},[c(d.$slots,"default",{},void 0,!0)],6)],2))}}),b=y(f,[["__scopeId","data-v-00e066e8"]]);export{b as C};
//# sourceMappingURL=ContentLayout-DrPZmqye.js.map
