import{u as r}from"./userStore-D3APQgTa.js";import{W as n}from"./PlayerConfigProvider-Dod3TGLj.js";import{u as c}from"./workspaceStore-JLfI-nyq.js";import{e as d,R as i,f as m,g as f,j as o,w as u,m as l,ab as p,h as w}from"./jwt-decode.esm-BTkSWSoY.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="2dd7e499-c51e-4b77-951c-30be3d59d7b1",t._sentryDebugIdIdentifier="sentry-dbid-2dd7e499-c51e-4b77-951c-30be3d59d7b1")}catch{}})();const C=d({__name:"App",setup(t){document.documentElement.dataset.theme="light";const a=r(),e=c();return e.actions.fetch(),i(()=>a.jwt,e.actions.fetch),(b,_)=>{const s=p("RouterView");return o(e).state.workspace?(w(),m(n,{key:0,"main-color":o(e).state.workspace.mainColor,background:o(e).state.workspace.theme,"font-family":o(e).state.workspace.fontFamily,locale:o(e).state.workspace.language},{default:u(()=>[l(s,{style:{height:"100vh",width:"100%"}})]),_:1},8,["main-color","background","font-family","locale"])):f("",!0)}}});export{C as _};
//# sourceMappingURL=App.vue_vue_type_style_index_0_lang-DMxk8zk3.js.map
