import{C as p,_ as i}from"./View.vue_vue_type_script_setup_true_lang-Drw8uaAe.js";import{e as n,an as s,f as m,h as a,j as c}from"./jwt-decode.esm-BTkSWSoY.js";import"./router-Dhyutz1M.js";import"./ts.worker-BQIuSwVW.js";import"./fetch-oK4oSWxn.js";import"./record-ByQtEUH9.js";import"./SaveButton-B5qx2MBc.js";import"./ExclamationCircleOutlined-BndEgJj2.js";import"./CrudView-n97I6TXv.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-FalB7w3f.js";import"./constants-C5LkWXsh.js";import"./url-Dh-2B4RL.js";import"./PhDotsThreeVertical.vue-CYfSeFRW.js";import"./index-BKDGrwKH.js";import"./asyncComputed-DyfgKCRs.js";import"./omniChatStore-CzchNX3R.js";import"./contracts.generated-ByAyIWn2.js";import"./runnerData-Dk9JFgLq.js";import"./colorHelpers-DxukDxoj.js";import"./uuid-DNWN2up9.js";import"./PhCopySimple.vue-CtYcj4n2.js";import"./PhPencil.vue-sQBSadRO.js";import"./useCodebaseEvents-vk-z-2Wm.js";import"./index-Cx6QAF3K.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="6436b2cc-137d-4898-ba94-673e6300bb13",o._sentryDebugIdIdentifier="sentry-dbid-6436b2cc-137d-4898-ba94-673e6300bb13")}catch{}})();const G=n({__name:"EnvVars",setup(o){const t=s().params.projectId,e=new p(t);return(d,f)=>(a(),m(i,{"env-var-repository":c(e),mode:"console"},null,8,["env-var-repository"]))}});export{G as default};
//# sourceMappingURL=EnvVars-DB_WFU5V.js.map
