import{e as n,ai as r,N as i,y as s,h as c,m as d,j as f,b8 as p,aO as l}from"./jwt-decode.esm-BTkSWSoY.js";import{u}from"./organizationSwitcher-Dynbd3X0.js";import"./router-Dhyutz1M.js";import"./ts.worker-BQIuSwVW.js";import"./organization-BXLykhFT.js";import"./tables-rIQ95qBT.js";import"./record-ByQtEUH9.js";import"./string-BYKRCdEY.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[a]="cbb37fea-ecec-4992-8f78-8fe371eea3d1",o._sentryDebugIdIdentifier="sentry-dbid-cbb37fea-ecec-4992-8f78-8fe371eea3d1")}catch{}})();const m={class:"loading-container"},_=n({__name:"RootRedirector",setup(o){const a=u(),t=r();return i(async()=>{const e=await a.selectDefaultOrganization();e.name==="organization"&&e.params?.organizationId?window.location.href=`/organizations/${e.params.organizationId}`:e.name==="onboarding"?window.location.href="/onboarding":t.replace(e)}),(e,g)=>(c(),s("div",m,[d(f(p),{size:"large"})]))}}),k=l(_,[["__scopeId","data-v-a77ce5c1"]]);export{k as default};
//# sourceMappingURL=RootRedirector-FT0ZR6ng.js.map
